@@ -79,14 +79,20 @@ def is_logged():
 
 def Login_Apply():
     # Validation
-    if not['email']:
+    if not CTK.post['email']:
         return {'ret':'error', 'errors': {'email': _("Can not be empty")}}
-    if not['password']:
+    if not CTK.post['password']:
         return {'ret':'error', 'errors': {'password': _("Can not be empty")}}
 
     # Authenticate
+    prev_changes = CTK.cfg.has_changed()
+
     logged = log_in (CTK.post['email'], CTK.post['password'])
     if logged == True:
+        # Auto-save it there were no prev changes
+        if not prev_changes:
+            CTK.cfg.save()
+
         return {'ret':'ok'}
 
     return {'ret':'error', 'errors': {'password': _("Authentication failed")}}
