@@ -5,7 +5,7 @@
 # Authors:
 #      Alvaro Lopez Ortega <alvaro@alobbs.com>
 #
-# Copyright (C) 2001-2010 Alvaro Lopez Ortega
+# Copyright (C) 2001-2011 Alvaro Lopez Ortega
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of version 2 of the GNU General Public
@@ -76,27 +76,27 @@ NOTE_INDEX_USAGE      = N_('Remember that only "File Exists" rules and "List & S
 DEFAULT_HOST_NOTE     = N_("<p>The 'default' virtual server matches all the domain names.</p>")
 
 CUSTOM_MACROS_LIST = [
-    ('ip_remote',          N_("TODO: Description")),
-    ('ip_local',           N_("TODO: Description")),
-    ('protocol',           N_("TODO: Description")),
-    ('transport',          N_("TODO: Description")),
-    ('port_server',        N_("TODO: Description")),
-    ('query_string',       N_("TODO: Description")),
-    ('request_first_line', N_("TODO: Description")),
-    ('status',             N_("TODO: Description")),
-    ('now',                N_("TODO: Description")),
-    ('time_secs',          N_("TODO: Description")),
-    ('time_nsecs',         N_("TODO: Description")),
-    ('user_remote',        N_("TODO: Description")),
-    ('request',            N_("TODO: Description")),
-    ('request_original',   N_("TODO: Description")),
-    ('vserver_name',       N_("TODO: Description")),
-    ('vserver_name_req',   N_("TODO: Description")),
-    ('response_size',      N_("TODO: Description")),
-    ('http_host',          N_("TODO: Description")),
-    ('http_referrer',      N_("TODO: Description")),
-    ('http_user_agent',    N_("TODO: Description")),
-    ('http_cookie',        N_("TODO: Description")),
+    ('ip_remote',          N_("Remote IP address")),
+    ('ip_local',           N_("Local IP address")),
+    ('protocol',           N_("Request Protocol")),
+    ('transport',          N_("Transport type: http or https")),
+    ('port_server',        N_("Port of the server serving the request")),
+    ('query_string',       N_("The query string, if exists")),
+    ('request_first_line', N_("First line of HTTP request")),
+    ('status',             N_("Response status code")),
+    ('now',                N_("Time: in common log format time format")),
+    ('time_secs',          N_("Time: seconds since Epoch")),
+    ('time_nsecs',         N_("Time: milliseconds since Epoch")),
+    ('user_remote',        N_("Remote user (authentication)")),
+    ('request',            N_("URL path requested")),
+    ('request_original',   N_("URL path requested before any rewrite")),
+    ('vserver_name',       N_("Virtual Server nick name")),
+    ('vserver_name_req',   N_("Requested host (Host: header)")),
+    ('response_size',      N_("Size of the response in bytes")),
+    ('http_host',          N_("'Host:' header of the request")),
+    ('http_referrer',      N_("'Referrer:' header of the request")),
+    ('http_user_agent',    N_("'User-Agent:' header of the request")),
+    ('http_cookie',        N_("'Cookie:' header of the request")),
 ]
 
 
@@ -123,7 +123,9 @@ VALIDATIONS = [
     ("vserver![\d]+!ssl_certificate_key_file",   validations.is_local_file_exists),
     ("vserver![\d]+!ssl_ca_list_file",           validation_ca_list),
     ("vserver![\d]+!ssl_verify_depth",           validations.is_positive_int),
-    ("vserver![\d]+!logger!.+?!filename",        validations.parent_is_dir),
+    ("vserver![\d]+!error_writer!filename",      validations.can_create_file),
+    ("vserver![\d]+!error_writer!command",       validations.is_local_file_exists),
+    ("vserver![\d]+!logger!.+?!filename",        validations.can_create_file),
     ("vserver![\d]+!logger!.+?!command",         validations.is_local_file_exists),
     ("vserver![\d]+!logger!x_real_ip_access$",   validations.is_ip_or_netmask_list),
 ]
