@@ -28,6 +28,7 @@ import re
 import os
 import imp
 import stat
+import sys
 import time
 import tarfile
 import traceback
@@ -36,6 +37,7 @@ import Maintenance
 import Library
 import Install_Log
 import SystemInfo
+import SystemStats
 import SaveButton
 import Cherokee
 import popen
@@ -83,7 +85,7 @@ URL_INSTALL_DONE_APPLY     = "%s/install/done/apply"     %(URL_MAIN)
 
 class InstallDialog (CTK.Dialog):
     def __init__ (self, info):
-        title = "%s: %s" %(_("Installation"), info['application_name'])
+        title = "%s  —  %s" %(info['application_name'], _("Cherokee Market"))
 
         CTK.Dialog.__init__ (self, {'title': title, 'width': 600, 'minHeight': 300})
         self.info = info
@@ -223,7 +225,7 @@ class Pay_Check (Install_Stage):
         xmlrpc = XmlRpcServer (OWS_APPS_INSTALL, user=OWS_Login.login_user, password=OWS_Login.login_password)
         install_info = xmlrpc.get_install_info (app_id, info)
 
-        Install_Log.log ("Waiting for the payment acknowledge…")
+        Install_Log.log ("Waiting for the payment acknowledge..")
 
         box = CTK.Box()
         if install_info.get('due_payment'):
@@ -292,7 +294,7 @@ class Download (Install_Stage):
         Install_Log.log ("Downloading %s" %(url_download))
 
         cont = CTK.Container()
-        cont += CTK.RawHTML ('<h2>%s %s</h2>' %(_("Downloading"), app_name))
+        cont += CTK.RawHTML ('<h2>%s %s</h2>' %(_("Installing"), app_name))
         cont += CTK.RawHTML ('<p>%s</p>' %(_('The application is being downloaded. Hold on tight!')))
         cont += downloader
         cont += buttons
@@ -308,7 +310,7 @@ class Download_Error (Install_Stage):
         Install_Log.log ("Downloading Error: %s" %(url_download))
 
         cont = CTK.Container()
-        cont += CTK.RawHTML ('<h2>%s %s</h2>' %(_("Downloading"), app_name))
+        cont += CTK.RawHTML ('<h2>%s %s</h2>' %(_("Installing"), app_name))
         cont += CTK.RawHTML (_("There was an error downloading the application. Please contact us if the problem persists."))
 
         buttons = CTK.DruidButtonsPanel()
@@ -390,6 +392,9 @@ def _Setup_unpack():
 
     # Uncompress
     try:
+        if sys.version_info < (2,5): # tarfile module prior to 2.5 is useless to us: http://bugs.python.org/issue1509889
+            raise tarfile.CompressionError
+
         Install_Log.log ("Unpacking %s with Python" %(package_path))
         tar = tarfile.open (package_path, 'r:gz')
         for tarinfo in tar:
@@ -423,12 +428,12 @@ class Setup (Install_Stage):
         app_name = CTK.cfg.get_val('tmp!market!install!app!application_name')
 
         box = CTK.Box()
-        box += CTK.RawHTML ("<h2>%s %s</h2>" %(_("Setting up"), app_name))
-        box += CTK.RawHTML ("<p>%s</p>" %(_("Unpacking application…")))
+        box += CTK.RawHTML ("<h2>%s %s</h2>" %(_("Installing"), app_name))
+        box += CTK.RawHTML ("<h1>%s</h1>" %(_("Unpacking application…")))
 
         # Unpack
         commands = [({'function': _Setup_unpack, 'description': _("The applicaction is being unpacked…")})]
-        progress = CommandProgress.CommandProgress (commands, URL_INSTALL_POST_UNPACK)
+        progress = CommandProgress.CommandProgress (commands, URL_INSTALL_POST_UNPACK, props={'style': 'display:none;'})
         box += progress
         return box.Render().toStr()
 
@@ -458,8 +463,8 @@ class Post_unpack (Install_Stage):
             box += CTK.RawHTML (js = CTK.DruidContent__JS_to_goto (box.id, URL_INSTALL_SETUP_EXTERNAL))
             return box.Render().toStr()
 
-        box += CTK.RawHTML ("<h2>%s %s</h2>" %(_("Setting up"), app_name))
-        box += CTK.RawHTML ("<p>%s</p>" %(_("Post unpacking set up…")))
+        box += CTK.RawHTML ("<h2>%s %s</h2>" %(_("Installing"), app_name))
+        box += CTK.RawHTML ("<p>%s</p>" %(_("Setting it up…")))
 
         progress = CommandProgress.CommandProgress (commands, URL_INSTALL_SETUP_EXTERNAL)
         box += progress
@@ -491,8 +496,6 @@ class Install_Done_Content (Install_Stage):
         app_name    = CTK.cfg.get_val('tmp!market!install!app!application_name')
         cfg_changes = CTK.cfg.get_val('tmp!market!install!cfg_previous_changes')
 
-        box = CTK.Box()
-
         # Finished
         finished_file = os.path.join (root, "finished")
         Install_Log.log ("Creating %s" %(finished_file))
@@ -502,12 +505,9 @@ class Install_Done_Content (Install_Stage):
         # Normalize CTK.cfg
         CTK.cfg.normalize ('vserver')
 
-        # Clean up CTK.cfg
-        for k in CTK.cfg.keys('tmp!market!install'):
-            if k != 'app':
-                del (CTK.cfg['tmp!market!install!%s'%(k)])
-
         # Save configuration
+        box = CTK.Box()
+
         if not int(cfg_changes):
             CTK.cfg.save()
             Install_Log.log ("Configuration saved.")
@@ -522,15 +522,59 @@ class Install_Done_Content (Install_Stage):
         box += CTK.RawHTML ('<h2>%s %s</h2>' %(app_name, _("has been installed successfully")))
         box += CTK.RawHTML ("<p>%s</p>" %(_(NOTE_THANKS_P1)))
 
+        # Save / Visit
         if int(cfg_changes):
             box += CTK.RawHTML ("<p>%s</p>" %(_(NOTE_SAVE_RESTART)))
 
+        elif Cherokee.server.is_alive():
+            install_type = CTK.cfg.get_val ('tmp!market!install!target')
+            nick         = CTK.cfg.get_val ('tmp!market!install!target!vserver')
+            vserver_n    = CTK.cfg.get_val ('tmp!market!install!target!vserver_n')
+            directory    = CTK.cfg.get_val ('tmp!market!install!target!directory')
+
+            # Host
+            if vserver_n and not nick:
+                nick = CTK.cfg.get_val ("vserver!%s!nick"%(vserver_n))
+
+            if nick.lower() == "default":
+                sys_stats = SystemStats.get_system_stats()
+                nick = sys_stats.hostname
+
+            # Ports
+            ports = []
+            for b in CTK.cfg['server!bind'] or []:
+                port = CTK.cfg.get_val ('server!bind!%s!port'%(b))
+                if port:
+                    ports.append (port)
+
+            nick_port = nick
+            if ports and not '80' in ports:
+                nick_port = '%s:%s' %(nick, ports[0])
+
+            # URL
+            url = ''
+            if install_type == 'vserver' and nick:
+                url  = 'http://%s/'%(nick_port)
+            elif install_type == 'directory' and vserver_n and directory:
+                nick = CTK.cfg.get_val ('vserver!%s!nick'%(vserver_n))
+                url  = 'http://%s%s/'%(nick_port, directory)
+
+            if url:
+                box += CTK.RawHTML ('<p>%s ' %(_("You can now visit")))
+                box += CTK.LinkWindow (url, CTK.RawHTML (_('your new application')))
+                box += CTK.RawHTML (' on a new window.</p>')
+
         box += CTK.RawHTML ("<h1>%s</h1>" %(_(NOTE_THANKS_P2)))
 
         buttons = CTK.DruidButtonsPanel()
         buttons += CTK.DruidButton_Close(_('Close'))
         box += buttons
 
+        # Clean up CTK.cfg
+        for k in CTK.cfg.keys('tmp!market!install'):
+            if k != 'app':
+                del (CTK.cfg['tmp!market!install!%s'%(k)])
+
         return box.Render().toStr()
 
 
